
#' 2D and 3D Hive Plots for R
#'
#' Creates and plots 2D and 3D hive plots. Hive plots are a unique method of
#' displaying networks of many types in which node properties are mapped to
#' axes using meaningful properties rather than being arbitrarily positioned.
#' The hive plot concept was invented by Martin Krzywinski at the Genome
#' Science Center (www.hiveplot.net/).  Keywords: networks, food webs, linnet,
#' systems biology, bioinformatics.
#'
#'
#' @name HiveR-package
#' @aliases HiveR-package HiveR
#' @docType package
#' @author Bryan A. Hanson, DePauw University, Greencastle Indiana USA
#' @keywords package
"_PACKAGE"
